import React from "react";
import clsx from "clsx";
import useDocusaurusContext from "@docusaurus/useDocusaurusContext";
import Layout from "@theme/Layout";

import styles from "./index.module.css";
import Link from "@docusaurus/Link";
import Head from "@docusaurus/Head";

function HomepageHeader() {
  const { siteConfig } = useDocusaurusContext();
  return (
    <header className={clsx("hero hero--primary", styles.heroBanner)}>
      <div className="container">
        <h1 className="hero__title">{siteConfig.title}</h1>
        <p className="hero__subtitle">{siteConfig.tagline}</p>
        <div className={styles.buttons}>
          <Link className="button button--secondary button--lg" to="/java">
            <i class="fa-brands fa-java"></i> Java
          </Link>
          <Link className="button button--secondary button--lg" to="/robot">
            <i class="fa-solid fa-robot"></i> Robot
          </Link>
        </div>
      </div>
    </header>
  );
}

export default function Home() {
  const { siteConfig } = useDocusaurusContext();
  return (
    <Layout title={`${siteConfig.title}`} description="Documentation PLS 5618">
      <Head>
        <script
          src="https://kit.fontawesome.com/9e215b042a.js"
          crossorigin="anonymous"
        ></script>
      </Head>
      <HomepageHeader />
      <main></main>
    </Layout>
  );
}
